# Copyright 2019 Cumulus Networks, Inc.  All Rights reserved.
#
# This software is subject to the Cumulus Networks End User License Agreement
# available at the following locations:
#
# Internet: https://cumulusnetworks.com/downloads/eula/latest/view/
# Cumulus Linux systems: /usr/share/cumulus/EULA.txt


"""
Usage:
    netq login <text-user-name>
    netq login username <text-user-name> password <text-user-password>
    netq whoami
    netq logout


Options:
    login                       : Log into netq cloud account
    whoami                      : Current user logged into netq cloud account
    logout                      : Log out of netq cloud account
    username                    : NetQ username
    password                    : NetQ user password
    <text-user-name>            : Username of netq cloud account
    <text-user-password>        : Password of netq cloud account
"""

from netq_apps.lib.cloud_login import NetqAccount
from netq_apps.modules import NetqModule, RC_SUCCESS, RC_FAIL
from netq_lib.common.configuration import get_config
from netq_lib.common.enums import ConfKw
from netq_lib.common.utils import RED_T, get_logger

app = NetqModule()
current_config = get_config(ConfKw.NETQD)
netq_cli = current_config.get(ConfKw.NETQ_CLI)
logger = get_logger(ConfKw.NETQD, current_config)
netq_account = NetqAccount(ip=netq_cli.get(ConfKw.SERVER), port=netq_cli.get(ConfKw.PORT), logger=logger)


@app.route('login')
def dummy_login(cli, netq):
    return RC_SUCCESS


@app.route('login username')
def cli_login_username(cli, netq):
    try:
        username = cli.get('<text-user-name>')
        password = cli.get('<text-user-password>')
        netq_account.login(netq.session_id, username, password)
    except Exception as ex:
        print(RED_T(str(ex.message)))
        return RC_FAIL
    else:
        print('Successfully logged in as {}'.format(username))
        return RC_SUCCESS


def cli_login(session_id, username):
    try:
        netq_account.login(session_id, username)
    except Exception as ex:
        print(RED_T(str(ex.message)))
        return RC_FAIL
    else:
        print('Successfully logged in as {}'.format(username))
        return RC_SUCCESS


@app.route('add user')
def cli_add_user(cli, netq):
    print('command not supported yet')
    return RC_SUCCESS


@app.route('del user')
def cli_del_user(cli, netq):
    print('command not supported yet')
    return RC_SUCCESS


@app.route('whoami')
def cli_whoami(cli, netq):
    try:
        username = netq_account.whoami(session_id=netq.session_id)
    except Exception as ex:
        print(RED_T(str(ex.message)))
        return RC_FAIL
    else:
        print(username)
        return RC_SUCCESS


@app.route('logout')
def cli_logout(cli, netq):
    try:
        username = netq_account.logout(session_id=netq.session_id)
    except Exception as ex:
        print(RED_T(str(ex.message)))
        return RC_FAIL
    else:
        print('Successfully logged out {}'.format(username))
        return RC_SUCCESS

